APICacheDBModel class

Inheritance
  • Object
  • CacheDBBaseModel
  • APICacheDBModel

Constructors

APICacheDBModel({required String key, required String syncData, int? syncTime})

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pairinherited
key ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syncData ↔ String
getter/setter pair
syncTime ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

table ↔ String
getter/setter pair

Static Methods

fromMap(Map<String, dynamic> map) → APICacheDBModel