Failure class

Represents a failure from ApiServices, carrying the error type, HTTP/internal code, and a human-readable message.

Implemented types

Constructors

Failure(ErrorSource errorType, ResponseCode code, String message)
const

Properties

code → ResponseCode
final
errorType → ErrorSource
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited